import pySecDec as psd, sympy as sp, json

if __name__ == "__main__":
    li = psd.LoopIntegralFromGraph(
        internal_lines = [['mt',[1,4]], ['mw',[4,2]], ['0',[2,3]],
                          ['0',[4,5]], ['0',[1,5]], ['mz',[5,3]]],
        external_lines = [['p1',1], ['p2',2], ['p3',3]],
        regulators = ['eps'],
        replacement_rules = [
            ('p1', '-p2-p3'),
            ('p2*p2', '0'),
            ('p3*p3', '0'),
            ('p2*p3', 's/2'),
            ('mw**2', 'mwsq'),
            ('mz**2', 'mzsq'),
            ('mt**2', 'mtsq')])

    terms = psd.loop_regions(name = 'muon_decay2L',
                             loop_integral = li,
                             smallness_parameter = 'mtsq',
                             decomposition_method = 'geometric',
                             expansion_by_regions_order = 1)

    term_by_prefactor_exponent = {}
    for term in terms:
        coefficient, exponent = sp.sympify(str(term.prefactor)).as_coeff_exponent(sp.sympify('mtsq'))
        term = term._replace(prefactor = coefficient)
        term_by_prefactor_exponent.setdefault(str(exponent), [])
        term_by_prefactor_exponent[str(exponent)].append(term)

    prefactor_exponent_by_name = {}
    for i, (exponent, term) in enumerate(sorted(term_by_prefactor_exponent.items())):
        prefactor_exponent_by_name[f'prefactor_{i+1}'] = exponent
        psd.sum_package(f'prefactor_{i+1}',
                        term,
                        regulators = ['eps'],
                        requested_orders = [0],
                        real_parameters = ['s', 'mwsq', 'mzsq'])

    with open('prefactor_exponent_by_name.json', 'w') as f:
        json.dump(prefactor_exponent_by_name, f)
