from pySecDec.integral_interface import DistevalLibrary
import json
import sympy as sp

with open('prefactor_exponent_by_name.json') as f:
    prefactor_exponent_by_name = json.load(f)

result_by_prefactor_exponent = {}
for name, exponent in prefactor_exponent_by_name.items():
    loop_integral = DistevalLibrary(f'{name}/disteval/{name}.json')
    result_by_prefactor_exponent[exponent] = loop_integral(
            parameters = {'s': 3, 'mwsq': 0.78, 'mzsq': 1.0},
            epsrel = 1e-4, points = 1e4, format = 'sympy',
            number_of_presamples = 1e4, timeout = None)

print('Result:')
for exponent, str_result in result_by_prefactor_exponent.items():
    result = sp.sympify(str_result)
    val = result[0].subs({"plusminus": 0})
    err = result[0].coeff("plusminus")
    print(f'''\
  +mtsq^({exponent})*(
    +1/eps^2*(({val.coeff("eps",-2)}) +/- ({err.coeff("eps",-2)}))
    +1/eps^1*(({val.coeff("eps",-1)}) +/- ({err.coeff("eps",-1)}))
    +  eps^0*(({val.coeff("eps",0)}) +/- ({err.coeff("eps",0)}))
  )''')
